==> ejc-accplat-api-3.0.0-20240112.091425-111-sources.jar: com/ejianc/business/accplat/originvoucher/vo/OriginVoucherAuxiliaryVO.java <==
package com.ejianc.business.accplat.originvoucher.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 原始凭证分录核算项
 *
 * @author generator
 *
 */
@ApiModel("原始凭证分录核算项")
public class OriginVoucherAuxiliaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("辅助项id")
    private Long auxiliaryId;
    @ApiModelProperty("辅助项编码")
    private String auxiliaryCode;
    @ApiModelProperty("辅助项名称")
    private String auxiliaryName;
    @ApiModelProperty("辅助核算项值id")
    private Long auxiliaryValueId;
    @ApiModelProperty("辅助核算项值编码")
    private String auxiliaryValueCode;
    @ApiModelProperty("辅助核算项值名称")
    private String auxiliaryValueName;
    @ApiModelProperty("分录id")
    private Long entryId;
    @ApiModelProperty("原始凭证id")
    private Long originVoucherId;
    @ApiModelProperty("财务辅助核算项编码")
    private String auxiliaryFsCode;
    @ApiModelProperty("财务辅助核算项值编码")
    private String auxiliaryFsValue;


    /**
     * 辅助项id
     */
    public Long getAuxiliaryId() {
        return auxiliaryId;
    }

    /**
     * 辅助项id
     */
    public void setAuxiliaryId(Long auxiliaryId) {
        this.auxiliaryId = auxiliaryId;
    }

    /**
     * 辅助项编码
     */
    public String getAuxiliaryCode() {
        return auxiliaryCode;
    }

    /**
     * 辅助项编码
     */
    public void setAuxiliaryCode(String auxiliaryCode) {
        this.auxiliaryCode = auxiliaryCode;
    }

    /**
     * 辅助项名称
     */
    public String getAuxiliaryName() {
        return auxiliaryName;
    }

    /**
     * 辅助项名称
     */
    public void setAuxiliaryName(String auxiliaryName) {
        this.auxiliaryName = auxiliaryName;
    }

    /**
     * 辅助核算项值id
     */
    public Long getAuxiliaryValueId() {
        return auxiliaryValueId;
    }

    /**
     * 辅助核算项值id
     */
    public void setAuxiliaryValueId(Long auxiliaryValueId) {
        this.auxiliaryValueId = auxiliaryValueId;
    }

    /**
     * 辅助核算项值编码
     */
    public String getAuxiliaryValueCode() {
        return auxiliaryValueCode;
    }

    /**
     * 辅助核算项值编码
     */
    public void setAuxiliaryValueCode(String auxiliaryValueCode) {
        this.auxiliaryValueCode = auxiliaryValueCode;
    }

    /**
     * 辅助核算项值名称
     */
    public String getAuxiliaryValueName() {
        return auxiliaryValueName;
    }

    /**
     * 辅助核算项值名称
     */
    public void setAuxiliaryValueName(String auxiliaryValueName) {
        this.auxiliaryValueName = auxiliaryValueName;
    }

    /**
     * 分录id
     */
    public Long getEntryId() {
        return entryId;
    }

    /**
     * 分录id
     */
    public void setEntryId(Long entryId) {
        this.entryId = entryId;
    }

    /**
     * 原始凭证id
     */
    public Long getOriginVoucherId() {
        return originVoucherId;
    }

    /**
     * 原始凭证id
     */
    public void setOriginVoucherId(Long originVoucherId) {
        this.originVoucherId = originVoucherId;
    }

    /**
     * 财务辅助核算项编码
     */
    public String getAuxiliaryFsCode() {
        return auxiliaryFsCode;
    }

    /**
     * 财务辅助核算项编码
     */
    public void setAuxiliaryFsCode(String auxiliaryFsCode) {
        this.auxiliaryFsCode = auxiliaryFsCode;
    }

    /**
     * 财务辅助核算项值编码
     */
    public String getAuxiliaryFsValue() {
        return auxiliaryFsValue;
    }

    /**
     * 财务辅助核算项值编码
     */
    public void setAuxiliaryFsValue(String auxiliaryFsValue) {
        this.auxiliaryFsValue = auxiliaryFsValue;
    }

}

==> ejc-accplat-api-3.0.0-20240124.041634-149-sources.jar: com/ejianc/business/accplat/originvoucher/vo/OriginVoucherAuxiliaryVO.java <==
package com.ejianc.business.accplat.originvoucher.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 原始凭证分录核算项
 *
 * @author generator
 *
 */
@ApiModel("原始凭证分录核算项")
public class OriginVoucherAuxiliaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("辅助项id")
    private Long auxiliaryId;
    @ApiModelProperty("辅助项编码")
    private String auxiliaryCode;
    @ApiModelProperty("辅助项名称")
    private String auxiliaryName;
    @ApiModelProperty("辅助核算项值id")
    private Long auxiliaryValueId;
    @ApiModelProperty("辅助核算项值编码")
    private String auxiliaryValueCode;
    @ApiModelProperty("辅助核算项值名称")
    private String auxiliaryValueName;
    @ApiModelProperty("分录id")
    private Long entryId;
    @ApiModelProperty("原始凭证id")
    private Long originVoucherId;
    @ApiModelProperty("财务辅助核算项编码")
    private String auxiliaryFsCode;
    @ApiModelProperty("财务辅助核算项值编码")
    private String auxiliaryFsValue;


    private Long compareAppId; // 对照数据id


    public Long getCompareAppId() {
        return compareAppId;
    }

    public void setCompareAppId(Long compareAppId) {
        this.compareAppId = compareAppId;
    }

    /**
     * 辅助项id
     */
    public Long getAuxiliaryId() {
        return auxiliaryId;
    }

    /**
     * 辅助项id
     */
    public void setAuxiliaryId(Long auxiliaryId) {
        this.auxiliaryId = auxiliaryId;
    }

    /**
     * 辅助项编码
     */
    public String getAuxiliaryCode() {
        return auxiliaryCode;
    }

    /**
     * 辅助项编码
     */
    public void setAuxiliaryCode(String auxiliaryCode) {
        this.auxiliaryCode = auxiliaryCode;
    }

    /**
     * 辅助项名称
     */
    public String getAuxiliaryName() {
        return auxiliaryName;
    }

    /**
     * 辅助项名称
     */
    public void setAuxiliaryName(String auxiliaryName) {
        this.auxiliaryName = auxiliaryName;
    }

    /**
     * 辅助核算项值id
     */
    public Long getAuxiliaryValueId() {
        return auxiliaryValueId;
    }

    /**
     * 辅助核算项值id
     */
    public void setAuxiliaryValueId(Long auxiliaryValueId) {
        this.auxiliaryValueId = auxiliaryValueId;
    }

    /**
     * 辅助核算项值编码
     */
    public String getAuxiliaryValueCode() {
        return auxiliaryValueCode;
    }

    /**
     * 辅助核算项值编码
     */
    public void setAuxiliaryValueCode(String auxiliaryValueCode) {
        this.auxiliaryValueCode = auxiliaryValueCode;
    }

    /**
     * 辅助核算项值名称
     */
    public String getAuxiliaryValueName() {
        return auxiliaryValueName;
    }

    /**
     * 辅助核算项值名称
     */
    public void setAuxiliaryValueName(String auxiliaryValueName) {
        this.auxiliaryValueName = auxiliaryValueName;
    }

    /**
     * 分录id
     */
    public Long getEntryId() {
        return entryId;
    }

    /**
     * 分录id
     */
    public void setEntryId(Long entryId) {
        this.entryId = entryId;
    }

    /**
     * 原始凭证id
     */
    public Long getOriginVoucherId() {
        return originVoucherId;
    }

    /**
     * 原始凭证id
     */
    public void setOriginVoucherId(Long originVoucherId) {
        this.originVoucherId = originVoucherId;
    }

    /**
     * 财务辅助核算项编码
     */
    public String getAuxiliaryFsCode() {
        return auxiliaryFsCode;
    }

    /**
     * 财务辅助核算项编码
     */
    public void setAuxiliaryFsCode(String auxiliaryFsCode) {
        this.auxiliaryFsCode = auxiliaryFsCode;
    }

    /**
     * 财务辅助核算项值编码
     */
    public String getAuxiliaryFsValue() {
        return auxiliaryFsValue;
    }

    /**
     * 财务辅助核算项值编码
     */
    public void setAuxiliaryFsValue(String auxiliaryFsValue) {
        this.auxiliaryFsValue = auxiliaryFsValue;
    }

}
